@@ -1,6 +1,6 @@
 from typing import List, Optional
 
-from pydantic import BaseModel, constr, validator
+from pydantic import BaseModel, constr, validator, Extra
 from sqlalchemy import create_engine
 
 from ..core.errors import DBError
@@ -14,6 +14,9 @@ class RedshiftDDL(DDL):
         type: Optional[str]
         columns: List[str]
 
+        class Config:
+            extra = Extra.forbid
+
         @validator("type")
         def validate_type(cls, v, values):
             if v.upper() not in ("COMPOUND", "INTERLEAVED"):
