@@ -5,7 +5,7 @@ CREATE OR REPLACE FILE FORMAT {{ file_format }}
   TYPE = 'CSV'
   FIELD_DELIMITER = '\t'
   SKIP_HEADER = 1
-  NULL_IF = ('0000-00-00 00:00:00')
+  NULL_IF = ('NaN', '0000-00-00 00:00:00')
   EMPTY_FIELD_AS_NULL = true
   FIELD_OPTIONALLY_ENCLOSED_BY = '"'
   ESCAPE_UNENCLOSED_FIELD = '\\'
