@@ -1,7 +1,7 @@
 from pathlib import Path
 from typing import Dict, Any, Optional
 
-from pydantic import BaseModel, Field, FilePath, validator
+from pydantic import BaseModel, Field, FilePath, validator, Extra
 
 from ..core.errors import Exc, Ok, Err
 from ..database import Database
@@ -16,6 +16,9 @@ class Destination(BaseModel):
     db_schema: Optional[str] = Field(None, alias="schema")
     table: str
 
+    class Config:
+        extra = Extra.forbid
+
     @validator("tmp_schema")
     def can_use_tmp_schema(cls, v, values):
         if v is not None and not values["supports_schemas"]:
@@ -43,6 +46,9 @@ class Config(BaseModel):
     destination: Destination
     ddl: Optional[Dict[str, Any]]
 
+    class Config:
+        extra = Extra.forbid
+
     @validator("file_name", pre=True)
     def file_name_plus_folder(cls, v, values):
         return Path(values["sql_folder"], v)
